(is-hashbang-heading? block)Determines whether the given block is a hashbang heading.
Determines whether the given block is a hashbang heading.
(is-settext-heading? block)Determines whether the given block is a settext heading.
Determines whether the given block is a settext heading.
(is? block)Determines whether the given block is a heading block.
Determines whether the given block is a heading block.
(render-hashbang-heading block)Renders the hashbang heading block.
Renders the hashbang heading block.
(render-settext-heading block)Renders the settext heading block.
Renders the settext heading block.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |