Clojure only.

clarktown.parsers.horizontal-line-block


is?clj

(is? block)

Determines whether the given block is a horizontal line block.

Determines whether the given block is a horizontal line block.
sourceraw docstring

renderclj

(render _ _)

Renders the horizontal line block.

Renders the horizontal line block.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries