(is? block)Determines whether the given block is a horizontal line block.
Determines whether the given block is a horizontal line block.
(render _ _)Renders the horizontal line block.
Renders the horizontal line block.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |